==> nextcloud-app-deck-1%3a1.0.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/deck/l10n/ka_GE.js <==
OC.L10N.register(
    "deck",
    {
    "Deck" : "დასტა",
    "Personal" : "პირადი",
    "The card \"%s\" on \"%s\" has reached its due date." : "ბარათმა \"%s\" \"%s\"-ზე მიაღწია დანიშნულ დროს.",
    "The board \"%s\" has been shared with you by %s." : "დაფა \"%s\" თქვენთან გაზიარდა %s-ისთვის.",
    "{user} has shared the board %s with you." : "{user} მომხმარებელმა თქვენთან გააზიარა დაფა %s.",
    "Finished" : "დასრულდა",
    "To review" : "მიმოხილვისთვის",
    "Action needed" : "საჭიროა ქმედება",
    "Later" : "მოგვიანებით",
    "Done" : "დასრულებულია",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "ატვირთული ფაილი აჭარბებს php.ini-ში დაყენებულ upload_max_filesize დირექტივას",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "ატვირთული ფაილი აჭარბებს HTML ფორამაში მითითებულ MAX_FILE_SIZE დირექტივას",
    "No file was uploaded" : "ფაილი არ აიტვირთა",
    "Missing a temporary folder" : "დროებითი დირექტორია არ არსებობს",
    "Create new board" : "ახალი დაფის შექმნა",
    "Cancel" : "უარყოფა",
    "File already exists" : "ფაილი უკვე არსებობს",
    "Do you want to overwrite it?" : "გსურთ მისი გადაწერა?",
    "Filter by tag" : "ფილტრი ტეგებით",
    "Show archived cards" : "არქივირებული ბარათების ჩვენება",
    "Details" : "დეტალები",
    "Sharing" : "გაზიარება",
    "Tags" : "ტეგები",
    "Undo" : "დაბრუნება",
    "Can edit" : "შეუძლია შეცვალოს",
    "Can share" : "შეუძლია გააზიაროს",
    "Delete" : "წაშლა",
    "Add a new stack" : "დასტის დამატება",
    "Add card" : "ბარათის დამატება",
    "Edit" : "შეცვლა",
    "Due date" : "დროისთვის",
    "Remove due date" : "მოაშორეთ დანიშნულების დრო",
    "Description" : "აღწერა",
    "Formatting help" : "დახმარება ფორმატირებაზე",
    "Comments" : "კომენტარები",
    "Modified" : "შეიცვალა",
    "Created" : "შექმნილია",
    "Upload attachment" : "დანართის ატვირთვა",
    "Save" : "შენახვა",
    "Reply" : "პასუხი",
    "Update" : "განახლება",
    "(group)" : "(ჯგუფი)",
    "seconds ago" : "წამის წინ",
    "Archived boards" : "არქივირებული დაფები",
    "Shared boards" : "გაზიარებული დაფები",
    "Settings" : "პარამეტრები",
    "New board title" : "ახალი დაფის სახელი",
    "Share" : "გაზიარება",
    "Edit board" : "დაფის შეცვლა",
    "Archive board" : "დაფის არქივირება",
    "Unarchive board" : "დაფის ამოღება",
    "Delete board" : "დაფის გაუქმება",
    "Board details" : "დაფის დეტალები"
},
"nplurals=2; plural=(n!=1);");

==> nextcloud-app-deck-1%3a1.1.2-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/deck/l10n/ka_GE.js <==
OC.L10N.register(
    "deck",
    {
    "Deck" : "დასტა",
    "Personal" : "პირადი",
    "The card \"%s\" on \"%s\" has reached its due date." : "ბარათმა \"%s\" \"%s\"-ზე მიაღწია დანიშნულ დროს.",
    "The board \"%s\" has been shared with you by %s." : "დაფა \"%s\" თქვენთან გაზიარდა %s-ისთვის.",
    "{user} has shared the board %s with you." : "{user} მომხმარებელმა თქვენთან გააზიარა დაფა %s.",
    "Finished" : "დასრულდა",
    "To review" : "მიმოხილვისთვის",
    "Action needed" : "საჭიროა ქმედება",
    "Later" : "მოგვიანებით",
    "Done" : "დასრულებულია",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "ატვირთული ფაილი აჭარბებს php.ini-ში დაყენებულ upload_max_filesize დირექტივას",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "ატვირთული ფაილი აჭარბებს HTML ფორამაში მითითებულ MAX_FILE_SIZE დირექტივას",
    "No file was uploaded" : "ფაილი არ აიტვირთა",
    "Missing a temporary folder" : "დროებითი დირექტორია არ არსებობს",
    "Cancel" : "უარყოფა",
    "File already exists" : "ფაილი უკვე არსებობს",
    "Do you want to overwrite it?" : "გსურთ მისი გადაწერა?",
    "Filter by tag" : "ფილტრი ტეგებით",
    "Hide archived cards" : "არქივირებული ბარათების დამალვა",
    "Show archived cards" : "არქივირებული ბარათების ჩვენება",
    "Details" : "დეტალები",
    "Sharing" : "გაზიარება",
    "Tags" : "ტეგები",
    "Undo" : "დაბრუნება",
    "Can edit" : "შეუძლია შეცვალოს",
    "Can share" : "შეუძლია გააზიაროს",
    "Delete" : "წაშლა",
    "Add card" : "ბარათის დამატება",
    "Edit" : "შეცვლა",
    "Title" : "სათაური",
    "Members" : "წევრები",
    "Upload attachment" : "დანართის ატვირთვა",
    "Due date" : "დროისთვის",
    "Remove due date" : "მოაშორეთ დანიშნულების დრო",
    "Description" : "აღწერა",
    "Formatting help" : "დახმარება ფორმატირებაზე",
    "Comments" : "კომენტარები",
    "Modified" : "შეიცვალა",
    "Created" : "შექმნილია",
    "Save" : "შენახვა",
    "Reply" : "პასუხი",
    "Update" : "განახლება",
    "(group)" : "(ჯგუფი)",
    "seconds ago" : "წამის წინ",
    "Archived boards" : "არქივირებული დაფები",
    "Shared with you" : "გაზიარებული თქვენთან",
    "Edit board" : "დაფის შეცვლა",
    "Board details" : "დაფის დეტალები",
    "Today" : "დღეს",
    "Tomorrow" : "ხვალ",
    "This week" : "ამ კვირაში"
},
"nplurals=2; plural=(n!=1);");
